==> pypermod-0.3.0.tar.gz: pypermod-0.3.0/README.md <==
![](./httpdocs/small_pypermod_title.png)

# pypermod

This python package provides various tools to predict energy expenditure and recovery dynamics of an athlete. 
The name `pypermod` stands for __Python Performance Modeling__.

More details on the purpose of this package can be found in our manuscript __A hydraulic model outperforms work-balance models for predicting recovery kinetics from intermittent exercise__. 
You can find the preprint on [arXiv](). We provide scripts in the `example_scripts` folder of our [GitHub_repository](https://github.com/faweigend/pypermod) to recreate all plots and comparisons of the manuscript.

### Setup

If you aim to use the package for your own analysis you may want to install it via `pip3 install pypermod` without the need 
for a manual download. 

If you aim to work on the source code you may clone the [GitHub_repository](https://github.com/faweigend/pypermod). 
You can install the files from the repository by running `pip3 install -e <path_to_project_root>`.

### Usage

Please see the scripts in the `example_scripts` 
folder of our [GitHub_repository](https://github.com/faweigend/pypermod) for exemplary comparisons and applications. Three types of example scripts are available:

#### Compare to Data

Scripts that have a name that starts with `compare` recreate comparison plots of the [manuscript](). You may use them to investigate the data we extracted from other studies or to see examples for how to use `pypermod` agents to predict recovery ratios.

#### Fitting Tau

Scripts that have a name that starts with `fitting` recreate the fitting process of time constants for W'bal-weig and Chidnok comparisons in our [manuscript](). You may use them to further investigate our approaches to derive these time constants and how fitted models perform.

#### Simulate

Scripts that have a name that starts with `simulate` use one or several models to simulate energy dynamics of an athlete during exercise. Use these scripts as examples for how to use `pypermod` for predictions.

==> pypermod-1.0.0.tar.gz: pypermod-1.0.0/README.md <==
![](./httpdocs/small_pypermod_title.png)

# pypermod

[![PyPI](https://img.shields.io/pypi/v/pypermod.svg?style=for-the-badge)](https://pypi.python.org/pypi/pypermod)

This python package provides various tools to predict energy expenditure and recovery dynamics of an athlete. 
The name `pypermod` stands for __Python Performance Modeling__.

More details on the purpose of this package can be found in our manuscript __A hydraulic model outperforms work-balance models for predicting recovery kinetics from intermittent exercise__. 
You can find the preprint on [arXiv](https://arxiv.org/abs/2108.04510). 

You may also want to check our detailed video presentation at [STARS](https://www.clearinghouseforsport.gov.au/digital-media/conferences/2020/stars/modelling-energy-expenditure-and-recovery-investigation-and-validation-of-a-three-component-hydraulic-model).

If you make use of this project, we would be grateful if you star the repository and/or cite our paper.
```
@misc{weigend2021hydraulic,
      title={A hydraulic model outperforms work-balance models for predicting recovery kinetics from intermittent exercise}, 
      author={Fabian C. Weigend and David C. Clarke and Oliver Obst and Jason Siegler},
      year={2021},
      eprint={2108.04510},
      archivePrefix={arXiv},
      primaryClass={cs.OH}
}
```

### Setup

If you aim to use the package for your own analysis you may want to install it via `pip3 install pypermod` without the need 
for a manual download. 

If you aim to work on the source code you may clone the [GitHub_repository](https://github.com/faweigend/pypermod). 
You can install the files from the repository by running `pip3 install -e <path_to_project_root>`.

### Usage

Please see the scripts in the `example_scripts` 
folder of our [GitHub_repository](https://github.com/faweigend/pypermod) for example applications on how to use the package. Three types of example scripts are available:

#### Compare to Data

Scripts that have a name that starts with `compare` recreate comparison plots of the [manuscript](). You may use them to investigate the data we extracted from other studies or to see examples for how to use `pypermod` agents to predict recovery ratios.

#### Fitting Tau

Scripts that have a name that starts with `fitting` recreate the fitting process of time constants for W'bal-weig and Chidnok comparisons in our [manuscript](). You may use them to further investigate our approaches to derive these time constants and how fitted models perform.

#### Simulate

Scripts that have a name that starts with `simulate` use one or several models to simulate energy dynamics of an athlete during exercise. Use these scripts as examples for how to use `pypermod` for predictions.
